@@ -61,7 +61,14 @@ class Connector(Protocol):
 
 class LocalConnector(Connector):
     def __init__(self, directory=None):
-        self.directory = directory or os.environ["OELEO_BASE_DIR_TO"]
+        # TODO: check if it is best to default to TO DIR or FROM DIR or if it should break instead
+        if directory is not None:
+            self.directory = directory
+        else:
+            self.directory = os.environ["OELEO_BASE_DIR_FROM"]
+            log.debug("No directory passed to LocalConnector, defaulting to OELEO_BASE_DIR_FROM:", self.directory)
+
+        self.directory = Path(self.directory)
 
     def __str__(self):
         text = "LocalConnector"
@@ -98,7 +105,13 @@ class SSHConnector(Connector):
         self.session_password = os.environ["OELEO_PASSWORD"]
         self.username = username or os.environ["OELEO_USERNAME"]
         self.host = host or os.environ["OELEO_EXTERNAL_HOST"]
-        self.directory = directory or os.environ["OELEO_BASE_DIR_TO"]
+
+        if directory is not None:
+            self.directory = directory
+        else:
+            self.directory = os.environ["OELEO_BASE_DIR_TO"]
+            log.debug("No directory passed to SSHConnector, defaulting to OELEO_BASE_DIR_TO:", self.directory)
+
         self.is_posix = is_posix
         self.use_password = use_password
         self.c = None
@@ -117,8 +130,13 @@ class SSHConnector(Connector):
     def _validate(self):
         if self.is_posix:
             self.directory = PurePosixPath(self.directory)
+            log.debug("On posix")
+            if str(self.directory).startswith(r"\\"):
+                log.warning("YOUR PATH STARTS WITH WINDOWS TYPE SEPARATOR")
         else:
             self.directory = PureWindowsPath(self.directory)
+            log.debug("Not on posix")
+        log.debug(f"The ssh directory is: {self.directory}")
 
     def connect(self, **kwargs) -> None:
         if self.use_password:
