@@ -5,13 +5,11 @@ from pathlib import Path
 
 import dotenv
 
-from checkers import ChecksumChecker
-from models import SimpleDbHandler
-from oeleo.connectors import register_password, LocalConnector, SharePointConnector
+from oeleo.connectors import register_password
 from oeleo.console import console
 from oeleo.schedulers import RichScheduler, SimpleScheduler
 from oeleo.utils import logger
-from oeleo.workers import simple_worker, ssh_worker, Worker, sharepoint_worker
+from oeleo.workers import simple_worker, ssh_worker, sharepoint_worker
 
 log = logger()
 
@@ -149,7 +147,19 @@ def example_with_sharepoint_connector():
     worker.run()
 
 
-main = example_with_sharepoint_connector
+def example_with_ssh_and_env():
+    print(" Single run SSH with env parameters ".center(80, "-"))
+    log.setLevel(logging.DEBUG)
+    log.info(f"Starting oeleo!")
+    dotenv.load_dotenv()
+    worker = ssh_worker()
+    worker.connect_to_db()
+    worker.check(update_db=True)
+    worker.filter_local()
+    worker.run()
+
+
+main = example_with_ssh_and_env
 
 if __name__ == "__main__":
     main()
